==> igniteui-react-charts-16.4.1.tgz: package/ES5/SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { SplineSeriesBase } from "./SplineSeriesBase";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, runOn, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { SplineSeriesBaseView } from "./SplineSeriesBaseView";
import { ISortingAxis_$type } from "./ISortingAxis";
var SplineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(SplineSeries, _super);
    function SplineSeries() {
        var _this = _super.call(this) || this;
        _this.qh = null;
        _this.qh = new CategoryLineRasterizer();
        _this.ab = SplineSeries.$;
        return _this;
    }
    SplineSeries.prototype.bf = function () {
        return new SplineSeriesView(this);
    };
    SplineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.qi = a;
    };
    SplineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    SplineSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c6();
    };
    SplineSeries.prototype.oe = function (a, b) {
        _super.prototype.oe.call(this, a, b);
        var c = b;
        var d = c.cl.d;
        var e = typeCast(SplineSeriesView.$, b);
        var f = a.f;
        var g = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        var h = false;
        var i = this.m5.c;
        if (i != null) {
            h = true;
        }
        if (h) {
            var j = new ScalerParams(0, b.bq, b.bp, this.po.b8, g);
            this.oa(f, -1, this.valueColumn.count, this.po, j, b.n);
        }
        var k = e.dc;
        var l = e.dd;
        var m = e.db;
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, true, false, true, false);
        this.m5.ae(m, false, true, false, false);
        m._opacity = 0.75 * this.m5.i;
        if (b.cp(a)) {
            e.c7(f.count, f, true, 1, this.om(f, f.count - 1, b.bp, b.bq), d, this.eq);
            b.cs(a);
        }
    };
    Object.defineProperty(SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    SplineSeries.$t = markType(SplineSeries, 'SplineSeries', SplineSeriesBase.$);
    return SplineSeries;
}(SplineSeriesBase));
export { SplineSeries };
var SplineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(SplineSeriesView, _super);
    function SplineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c5 = null;
        _this.df = new Path();
        _this.de = new Path();
        _this.dg = new Path();
        _this.da = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.c5 = a;
        return _this;
    }
    Object.defineProperty(SplineSeriesView.prototype, "dc", {
        get: function () {
            return this.df;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SplineSeriesView.prototype, "dd", {
        get: function () {
            return this.dg;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SplineSeriesView.prototype, "db", {
        get: function () {
            return this.de;
        },
        enumerable: true,
        configurable: true
    });
    SplineSeriesView.prototype.c6 = function () {
        this.de.aj = null;
        this.df.aj = null;
        this.dg.aj = null;
        this.an();
    };
    SplineSeriesView.prototype.c7 = function (a, b, c, d, e, f, g) {
        this.c5.qh.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c5.qh.m(this.df, this.de, this.dg, a, b, c, d, e, f, g);
        this.an();
    };
    SplineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.c9.aj = this.df.aj;
        this.da.aj = this.dg.aj;
        this.c8.aj = this.de.aj;
        var a = this.bk();
        this.c9._stroke = a;
        this.c9.ac = this.e.eu + 3;
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.c8._fill = a;
        this.c8._opacity = 1;
    };
    SplineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c8);
                a.s(this.c9);
                a.s(this.da);
            }
            else {
                a.s(this.de);
                a.s(this.df);
                a.s(this.dg);
            }
        }
    };
    SplineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.df, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.dg, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.de, "translucentShape", ["Translucent"]);
    };
    SplineSeriesView.$t = markType(SplineSeriesView, 'SplineSeriesView', SplineSeriesBaseView.$);
    return SplineSeriesView;
}(SplineSeriesBaseView));
export { SplineSeriesView };

==> igniteui-react-charts-16.6.4.tgz: package/ES5/SplineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { SplineSeriesBase } from "./SplineSeriesBase";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, runOn, markType } from "igniteui-react-core/ES5/type";
import { Path } from "igniteui-react-core/ES5/Path";
import { ScalerParams } from "./ScalerParams";
import { SplineSeriesBaseView } from "./SplineSeriesBaseView";
import { ISortingAxis_$type } from "./ISortingAxis";
var SplineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(SplineSeries, _super);
    function SplineSeries() {
        var _this = _super.call(this) || this;
        _this.qi = null;
        _this.qi = new CategoryLineRasterizer();
        _this.ab = SplineSeries.$;
        return _this;
    }
    SplineSeries.prototype.bf = function () {
        return new SplineSeriesView(this);
    };
    SplineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.qj = a;
    };
    SplineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    SplineSeries.prototype.ho = function (a, b) {
        _super.prototype.ho.call(this, a, b);
        var c = b;
        c.c8();
    };
    SplineSeries.prototype.of = function (a, b) {
        _super.prototype.of.call(this, a, b);
        var c = b;
        var d = c.cn.d;
        var e = typeCast(SplineSeriesView.$, b);
        var f = a.f;
        var g = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        var h = false;
        var i = this.m5.c;
        if (i != null) {
            h = true;
        }
        if (h) {
            var j = new ScalerParams(0, b.bs, b.br, this.pp.b8, g);
            this.ob(f, -1, this.valueColumn.count, this.pp, j, b.n);
        }
        var k = e.de;
        var l = e.df;
        var m = e.dd;
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, true, false, true, false);
        this.m5.ae(m, false, true, false, false);
        m._opacity = 0.75 * this.m5.i;
        if (b.cr(a)) {
            e.c9(f.count, f, true, 1, this.on(f, f.count - 1, b.br, b.bs), d, this.eq);
            b.cu(a);
        }
    };
    Object.defineProperty(SplineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.nt;
        },
        enumerable: true,
        configurable: true
    });
    SplineSeries.$t = markType(SplineSeries, 'SplineSeries', SplineSeriesBase.$);
    return SplineSeries;
}(SplineSeriesBase));
export { SplineSeries };
var SplineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(SplineSeriesView, _super);
    function SplineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c7 = null;
        _this.dh = new Path();
        _this.dg = new Path();
        _this.di = new Path();
        _this.dc = new Path();
        _this.db = new Path();
        _this.da = new Path();
        _this.c7 = a;
        return _this;
    }
    Object.defineProperty(SplineSeriesView.prototype, "de", {
        get: function () {
            return this.dh;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SplineSeriesView.prototype, "df", {
        get: function () {
            return this.di;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SplineSeriesView.prototype, "dd", {
        get: function () {
            return this.dg;
        },
        enumerable: true,
        configurable: true
    });
    SplineSeriesView.prototype.c8 = function () {
        this.dg.aj = null;
        this.dh.aj = null;
        this.di.aj = null;
        this.an();
    };
    SplineSeriesView.prototype.c9 = function (a, b, c, d, e, f, g) {
        this.c7.qi.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c7.qi.m(this.dh, this.dg, this.di, a, b, c, d, e, f, g);
        this.an();
    };
    SplineSeriesView.prototype.a9 = function () {
        _super.prototype.a9.call(this);
        this.db.aj = this.dh.aj;
        this.dc.aj = this.di.aj;
        this.da.aj = this.dg.aj;
        var a = this.bl();
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
        this.dc._stroke = a;
        this.dc.ac = this.e.eu + 3;
        this.da._fill = a;
        this.da._opacity = 1;
    };
    SplineSeriesView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.da);
                a.s(this.db);
                a.s(this.dc);
            }
            else {
                a.s(this.dg);
                a.s(this.dh);
                a.s(this.di);
            }
        }
    };
    SplineSeriesView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        this.e.a2.exportPathData(a, this.dh, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.di, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.dg, "translucentShape", ["Translucent"]);
    };
    SplineSeriesView.$t = markType(SplineSeriesView, 'SplineSeriesView', SplineSeriesBaseView.$);
    return SplineSeriesView;
}(SplineSeriesBaseView));
export { SplineSeriesView };
